@@ -1,3 +1,5 @@
+"""Pydantic model represents True Checker API jobs."""
+
 from datetime import datetime
 from enum import Enum
 from typing import Optional
@@ -6,6 +8,8 @@ from pydantic import BaseModel
 
 
 class JobStates(str, Enum):
+    """Available True Checker API job states."""
+
     TODO = "todo"
     IN_PROGRESS = "in_progress"
     DONE = "done"
@@ -13,7 +17,9 @@ class JobStates(str, Enum):
     ERROR = "error"
 
 
-class CheckJob(BaseModel):
+class CheckJob(BaseModel):  # pylint: disable=too-few-public-methods
+    """True Checker API job model."""
+
     id: str
     bot_id: int
     state: JobStates
